#
# spec file for package python-zc.buildout
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-zc.buildout
Version:        3.0.1
Release:        1.5
Summary:        System for managing development buildouts
License:        ZPL-2.1
Group:          Development/Languages/Python
URL:            https://pypi.python.org/pypi/zc.buildout
Source:         https://files.pythonhosted.org/packages/source/z/zc.buildout/zc.buildout-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       python-zc_buildout = %{version}
Obsoletes:      python-zc_buildout < %{version}
BuildArch:      noarch
# SECTION test requirements
# disabled because of unprovideable requirements and not shipped test files
#BuildRequires:  %%{python_module bobo}
#BuildRequires:  %%{python_module manuel}
#BuildRequires:  %%{python_module zc.recipe.deployment}
#BuildRequires:  %%{python_module zc.zdaemonrecipe}
#BuildRequires:  %%{python_module zdaemon}
#BuildRequires:  %%{python_module zope.testing}
# /SECTION
%python_subpackages

%description
System for managing development buildouts.

Buildout is a project designed to solve 2 problems:
 * Application-centric assembly and deployment
 * Repeatable assembly of programs from Python software distributions

%prep
%setup -q -n zc.buildout-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/buildout
%python_expand %fdupes %{buildroot}%{$python_sitelib}/zc/buildout
%python_expand %fdupes %{buildroot}%{$python_sitelib}/zc.buildout-2.9.5-py%{$python_version}.egg-info

#%%check
#%%python_exec setup.py test

%post
%python_install_alternative buildout

%postun
%python_uninstall_alternative buildout

%files %{python_files}
%doc README.rst CHANGES.rst COPYRIGHT.txt
%license LICENSE.txt
%{python_sitelib}/*
%python_alternative %{_bindir}/buildout

%changelog
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update 3.0.1 (2022-11-08)
  * Fixed import of packaging.markers. [maurits] (#621)
- Update to 3.0.0 (2022-11-07)
  * Add support for PEP 508 markers in section condition expressions. For example: [versions:python_version <= "3.9"]. [maurits] (#621)
  Bug fixes:
  * Command-line ‘extends’ now works with dirs in file names [gotcha] (cli-extends)
  * Add support for python311-315 in conditional section expressions. (#311)
  * Make compatible with pip 22.2+, restoring Requires-Python functionality there. Fixes issue 613. [maurits] (#613)
- Update to 3.0.0rc3 (2022-04-07)
  * Fix TypeError: dist must be a Distribution instance due to issue between setuptools and pip. (#600)
- Update to 3.0.0rc2 (2022-03-04)
  * add support for PEP496 environment markers (pep496)
  * Fix TypeError for missing required use_deprecated_html5lib with pip 22. Keep compatible with earlier pip versions. (#598)
- Update to 3.0.0rc1 (2021-12-16)
  * Call pip via python -m pip. (#569)
- Update to 3.0.0b5 (2021-11-29)
  * Fix when c extension implements namespace packages without the corresponding directories. (#589)
  * Honor command-line buildout:extends (#592)
- Update to 3.0.0b4 (2021-11-25)
  * Allow to run buildout in FIPS enabled environments. (#570)
  * Proper error message if extends-cache tries to expand ${section:variable} (#585)
  * Forward verbose option to pip (#576)
  * Check that file top_level.txt exists before opening. Add check for other files as well. (#582)
  * Return code of pip install subprocess is now properly returned to buildout. (#586)
- Update to 3.0.0b3 (2021-10-08)
  * Improve warning message when a section contains unused options. (#483)
  * Fix support of pip>=21.1 (#567)
  * Fix confusion when using multiple Python versions and installing packages with C extensions without proper binary wheel available. (#574)
  * Avoid broken jobs on Travis because of security on PRs (travis-pr)
- Update to 3.0.0b2 (2021-03-09)
  * Improve error message when a package version is not pinned and allow-picked-versions = false. (#481)
  * Fix FileNotFoundError when installing eggs with top-level directory without code (like doc). (#556)
  * Login to docker hub to avoid pull limits (travis)
  * Initialize towncrier (#519)
- Update to 3.0.0b1 (2021-03-07)
  * Fix issue with combination of > specs and extras and recent setuptools.
  * Fix issue with incrementing options from .buildout/default.cfg.
  * Support python37, python38 and python39 in conditional section expressions.
  * Fix bootstrapping for python27 and python35.
- Update to 3.0.0a2 (2020-05-25)
  * Ignore .git when computing signature of a recipe develop egg
  * Warn when the name passed to zc.recipe.egg:scripts is not defined in egg entry points.
  * Show pip warning about Python version only once.
  * Better patch for pkg_resources.Distribution.hashcmp performance.
- Update to 3.0.0a1 (2020-05-17)
  * Scripts: ensure eggs are inserted before site-packages in sys.path.
  * Fix forever loop when changing zc.buildout version via buildout.
  * Add support for Requires-Python metadata. Fragile monkeypatch that relies on pip._internal. Emits a warning when support is disabled due to changes in pip.
  * Use pip install instead of deprecated setuptools.easy_install.
  * Patch pkg_resources.Distribution to make install of unpinned versions quicker. Most obvious with setuptools.
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.13.8
  * Support python310-315 in conditional section expressions.
* Fri Sep 16 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to version 2.13.7:
  * Support python37, python38 and python39 in conditional section expressions.
* Sat Nov 27 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- - Change History:
  * *************
- update to version 2.13.6:
  - Allow to run buildout in FIPS enabled environments
  (`#570 <https://github.com/buildout/buildout/issues/570>`_)
- update to version 2.13.5:
  - Improve possible error message if using a too new version of ``setuptools``.
  (`#580 <https://github.com/buildout/buildout/issues/580>`_)
- update to version 2.13.4:
  - Pin ``setuptools < 52`` as setuptools removed support for ``easy_install`` in
  newer versions.
  (`#543 <https://github.com/buildout/buildout/issues/543>`_)
  - Support for Python 3.4 is no longer tested using automatic tests.
  - Add support for Python 3.7 and 3.8.
- update to version 2.13.3:
  - Fix DeprecationWarning about MutableMapping.
  (`#484 <https://github.com/buildout/buildout/issues/484>`_)
- update to version 2.13.2:
  - Fixed DeprecationWarning on python 3.7: "'U' mode is deprecated".
- update to version 2.13.1:
  - Documentation update for the new ``buildout query`` command.
- update to version 2.13.0:
  - Get information about the configuration with new command ``buildout query``.
- update to version 2.12.2:
  - Upon an error, buildout exits with a non-zero exit code. This now also works
  when running with ``-D``.
  - Fixed most 'Deprecation' and 'Resource' warnings.
- update to version 2.12.1:
  - zc.buildout now explicitly requests zc.recipe.egg >=2.0.6 now.
- update to version 2.12.0:
  - Add a new buildout option ``allow-unknown-extras`` to enable
  installing requirements that specify extras that do not exist. This
  needs a corresponding update to zc.recipe.egg. See `issue 457
  <https://github.com/buildout/buildout/issues/457>`_.
  zc.recipe.egg has been updated to 2.0.6 for this change.
- update to version 2.11.5:
  - Fix for `issue 295 <https://github.com/buildout/buildout/issues/295>`_. On
  windows, deletion of temporary egg files is more robust now.
- update to version 2.11.4:
  - Fix for `issue 451 <https://github.com/buildout/buildout/issues/451>`_:
  distributions with a version number that normalizes to a shorter version
  number (3.3.0 to 3.3, for instance) can be installed now.
- update to version 2.11.3:
  - Update to use the new PyPI at https://pypi.org/.
- update to version 2.11.2:
  - Fix for the #442 issue: AttributeError on
  ``pkg_resources.SetuptoolsVersion``.
- update to version 2.11.1:
  - Made upgrade check more robust. When using extensions, the improvement
  introduced in 2.11 could prevent buildout from restarting itself when it
  upgraded setuptools.
- update to version 2.11.0:
  - Installed packages are added to the working set immediately. This helps in
  some corner cases that occur when system packages have versions that
  conflict with our specified versions.
- update to version 2.10.0:
  - Setuptools 38.2.0 started supporting wheels. Through setuptools, buildout
  now also supports wheels! You need at least version 38.2.3 to get proper
  namespace support.
  This setuptools change interfered with buildout's recent support for
  `buildout.wheel <https://github.com/buildout/buildout.wheel>`_, resulting in
  a sudden "Wheels are not supported" error message (see `issue 435
  <https://github.com/buildout/buildout/issues/425>`_). Fixed by making
  setuptools the default, though you can still use the buildout.wheel if you
  want.
- update to version 2.9.6:
  - Fixed: could not install eggs when sdist file name and package name had different
  case.
- update to version 2.9.5:
  - Use HTTPS for PyPI's index.  PyPI redirects HTTP to HTTPS by default
  now so using HTTPS directly avoids the potential for that redirect
  being modified in flight.
- update to version 2.9.4:
  - Sort the distributions used to compute ``__buildout_signature__`` to
  ensure reproducibility under Python 3 or under Python 2 when ``-R``
  is used on ``PYTHONHASHSEED`` is set to ``random``. Fixes `issue 392
  <https://github.com/buildout/buildout/issues/392>`_.
  * *NOTE**: This may cause existing ``.installed.cfg`` to be
  considered outdated and lead to parts being reinstalled spuriously
  under Python 2.
  - Add support code for doctests to be able to easily measure code
  coverage. See `issue 397 <https://github.com/buildout/buildout/issues/397>`_.
- update to version 2.9.3:
  - Add more verbosity to ``annotate`` results with ``-v``
  - Select one or more sections with arguments after ``buildout annotate``.
- update to version 2.9.2:
  - Fixed: We unnecessarily used a function from newer versions of
  setuptools that caused problems when older setuptools or pkg_resources
  installs were present (as in travis.ci).
- update to version 2.9.1:
  - Fixed a minor packaging bug that broke the PyPI page.
- update to version 2.9.0:
  - Added new syntax to explicitly declare that a part depends on other part.
  See http://docs.buildout.org/en/latest/topics/implicit-parts.html
  - Internal refactoring to work with `buildout.wheel
  <https://github.com/buildout/buildout.wheel>`_.
  - Fixed a bugs in ``zc.buildout.testing.Buildout``. It was loading
  user-default configuration.  It didn't support calling the
  ``created`` method on its sections.
  - Fixed a bug (windows, py 3.4)
  When processing metadata on "old-style" distutils scripts, .exe stubs
  appeared in ``metadata_listdir``, in turn reading those burped with
  ``UnicodeDecodeError``. Skipping .exe stubs now.
- update to version 2.8.0:
  - Added a hook to enable a soon-to-be-released buildout extension to
  provide wheel support.
- update to version 2.7.1:
  - Fixed a bug introduced in 2.6.0:
  zc.buildout and its dependeoncies were reported as picked even when
  their versions were fixed in a ``versions`` section.  Worse, when the
  ``update-versions-file`` option was used, the ``versions`` section was
  updated needlessly on every run.
- update to version 2.7.0:
  - Added a buildout option, ``abi-tag-eggs`` that, when true, causes
  the `ABI tag <https://www.python.org/dev/peps/pep-0425/#abi-tag>`_
  for the buildout environment to be added to the eggs directory name.
  This is useful when switching Python implementations (e.g. CPython
  vs PyPI or debug builds vs regular builds), especially when
  environment differences aren't reflected in egg names.  It also has
  the side benefit of making eggs directories smaller, because eggs
  for different Python versions are in different directories.
- update to version 2.6.0:
  - Updated to work with the latest setuptools.
  - Added (verified) Python 3.6 support.
- update to version 2.5.3:
  - After a dist is fetched and put into its final place, compile its
  python files.  No longer wait with compiling until all dists are in
  place.  This is related to the change below about not removing an
  existing egg.  [maurits]
  - Do not remove an existing egg.  When installing an egg to a location
  that already exists, keep the current location (directory or file).
  This can only happen when the location at first did not exist and
  this changed during the buildout run.  We used to remove the
  previous location, but this could cause problems when running two
  buildouts at the same time, when they try to install the same new
  egg.  Fixes #307.  [maurits]
  - In ``zc.buildout.testing.system``, set ``TERM=dumb`` in the environment.
  This avoids invisible control characters popping up in some terminals,
  like ``xterm``.  Note that this may affect tests by buildout recipes.
  [maurits]
  - Removed Python 2.6 and 3.2 support.
  [do3cc]
- update to version 2.5.2:
  - Fixed ``-=`` and ``+=`` when extending sections. See #161.
  [puittenbroek]
- update to version 2.5.1:
  - Fix python 2 for downloading external config files with basic auth in the
  URL. Fixes #257.
- update to version 2.5.0:
  - Added more elaborate version and requirement information when there's a
  version conflict. Previously, you could get a report of a version conflict
  without information about which dependency requested the conflicing
  requirement.
  Now all this information is logged and displayed in case of an error.
  [reinout]
  - Dropped 3.2 support (at least in the automatic tests) as setuptools will
  soon stop supporting it. Added python 3.5 to the automatic tests.
  [reinout]
- update to version 2.4.7:
  - Fix for #279. Distutils script detection previously broke on windows with
  python 3 because it errored on ``.exe`` files.
  [reinout]
- update to version 2.4.6:
  - Relative paths are now also correctly generated for the current directory
  ("develop = .").
  [youngking]
- update to version 2.4.5:
  - More complete fix for #24. Distutils scripts are now also generated for
  develop eggs.
  [reinout]
- update to version 2.4.4:
  - zc.buildout is now also released as a wheel. (Note: buildout itself doesn't
  support installing wheels yet.)
  [graingert]
- update to version 2.4.3:
  - Added nested directory creation support
  [guyzmo]
- update to version 2.4.2:
  - If a downloaded config file in the "extends-cache" gets corrupted, buildout
  now tells you the filename in the cache. Handy for troubleshooting.
  [reinout]
- update to version 2.4.1:
  - Check the ``use-dependency-links`` option earlier.  This can give
  a small speed increase.
  [maurits]
  - When using python 2, urllib2 is used to work around Python issue 24599, which
  affects downloading from behind a proxy.
  [stefano-m]
- update to version 2.4.0:
  - Buildout no longer breaks on packages that contain a file with a non-ascii
  filename. Fixes #89 and #148.
  [reinout]
  - Undo breakage on Windows machines where ``sys.prefix`` can also be a
  ``site-packages`` directory:  don't remove it from ``sys.path``.  See
  https://github.com/buildout/buildout/issues/217 .
  - Remove assumption that ``pkg_resources`` is a module (untrue since
  release of `setuptools 8.3``).  See
  https://github.com/buildout/buildout/issues/227 .
  - Fix for #212. For certain kinds of conflict errors you'd get an UnpackError
  when rendering the error message. Instead of a nicely formatted version
  conflict message.
  [reinout]
  - Making sure we use the correct easy_install when setuptools is installed
  globally. See https://github.com/buildout/buildout/pull/232 and
  https://github.com/buildout/buildout/pull/222 .
  [lrowe]
  - Updated buildout's `travis-ci <https://travis-ci.org/buildout/buildout>`_
  configuration so that tests run much quicker so that buildout is easier and
  quicker to develop.
  [reinout]
  - Note: zc.recipe.egg has also been updated to 2.0.2 together with this
  zc.buildout release. Fixed: In ``zc.recipe.egg#custom`` recipe's ``rpath``
  support, don't assume path elements are buildout-relative if they start with
  one of the "special" tokens (e.g., ``$ORIGIN``).  See:
  https://github.com/buildout/buildout/issues/225.
  [tseaver]
  - ``download-cache``, ``eggs-directory`` and ``extends-cache`` are now
  automatically created if their parent directory exists. Also they can be
  relative directories (relative to the location of the buildout config file
  that defines them). Also they can now be in the form ``~/subdir``, with the
  usual convention that the ``~`` char means the home directory of the user
  running buildout.
  [lelit]
  - A new boostrap.py file is released (version 2015-07-01).
  - When bootstrapping, the ``develop-eggs/`` directory is first removed. This
  prevents old left-over ``.egg-link`` files from breaking buildout's careful
  package collection mechanism.
  [reinout]
  - The bootstrap script now accepts ``--to-dir``. Setuptools is installed
  there. If already available there, it is reused. This can be used to
  bootstrap buildout without internet access. Similarly, a local
  ``ez_setup.py`` is used when available instead of it being downloaded. You
  need setuptools 14.0 or higher for this functionality.
  [lrowe]
  - The bootstrap script now uses ``--buildout-version`` instead of
  ``--version`` to pick a specific buildout version.
  [reinout]
  - The bootstrap script now accepts ``--version`` which prints the bootstrap
  version. This version is the date the bootstrap.py was last changed. A date
  is handier or less confusing than either tracking zc.buildout's version or
  having a separate bootstrap version number.
  [reinout]
- update to version 2.3.1:
  - Fixed: Buildout merged single-version requirements with
  version-range requirements in a way that caused it to think there
  wasn't a single-version requirement.  IOW, buildout throught that
  versions were being picked when they weren't.
  - Suppress spurios (and possibly non-spurious) version-parsing warnings.
- update to version 2.3.0:
  - Buildout is now compatible with (and requires) setuptools 8.
- update to version 2.2.5:
  - Improved fix for #198: when bootstrapping with an extension, buildout was
  too strict on itself, resulting in an inability to upgrade or downgrade its
  own version.
  [reinout]
  - Setuptools must be at 3.3 or higher now. If you use the latest bootstrap
  from http://downloads.buildout.org/2/bootstrap.py you're all set.
  [reinout]
  - Installing *recipes* that themselves have dependencies used to fail with a
  VersionConflict if such a dependency was installed globally with a lower
  version. Buildout now ignores the version conflict in those cases and simply
  installs the correct version.
  [reinout]
- update to version 2.2.4:
  - Fix for #198: buildout 2.2.3 caused a version conflict when bootstrapping a
  buildout with a version pinned to an earlier one. Same version conflict
  could occur with system-wide installed packages that were newer than the
  pinned version.
  [reinout]
- update to version 2.2.3:
  - Fix #197, Python 3 regression
  [aclark4life]
- update to version 2.2.2:
  - Open files for ``exec()`` in universal newlines mode.  See
  https://github.com/buildout/buildout/issues/130
  - Add ``BUILDOUT_HOME`` as an alternate way to control how the user default
  configuration is found.
  - Close various files when finished writing to them. This avoids
  ResourceWarnings on Python 3, and better supports doctests under PyPy.
  - Introduce improved easy_install Install.install function. This is present
  in 1.5.X and 1.7X but was never merged into 2.X somehow.
- update to version 2.2.1:
  - ``distutils`` scripts: correct order of operations on ``from ... import``
  lines (see https://github.com/buildout/buildout/issues/134).
  - Add an ``--allow-site-packges`` option to ``bootstrap.py``, defaulting
  to False.  If the value is false, strip any "site packages" (as defined by
  the ``site`` module) from ``sys.path`` before attempting to import
  ``setuptools`` / ``pkg_resources``.
  - Updated the URL used to fetch ``ez_setup.py`` to the official, non-version-
  pinned version.
- update to version 2.2.0:
  - Handle both addition and subtraction of elements (+= and -=) on the same key
  in the same section. Forward-ported from buildout 1.6.
  - Suppress the useless ``Link to <URL> ***BLOCKED*** by --allow-hosts``
  error message being emitted by distribute / setuptools.
  - Extend distutils script generation to support module docstrings and
  __future__ imports.
  - Refactored picked versions logic to make it easier to use for plugins.
  - Use ``get_win_launcher`` API to find Windows launcher (falling back to
  ``resource_string`` for ``cli.exe``).
  - Remove ``data_files`` from ``setup.py``:  it was installing ``README.txt``
  in current directory during installation (merged from 1.x branch).
  - Switch dependency from ``distribute 0.6.x`` to ``setuptools 0.7.x``.
- update to version 2.1.0:
  - Meta-recipe support
  - Conditional sections
  - Buildout now accepts a ``--version`` command-line option to print
  its version.
  - Fixed: Builout didn't exit with a non-zero exit status if there was a:
    failure in combination with an upgrade.
  - Fixed: We now fail with an informative error when an old bootstrap:
    script causes buildout 2 to be used with setuptools.
  - Fixed: An error incorrectly suggested that buildout 2 implemented all:
    of the functionality of dumppickedversions.
  - Fixed: Buildout generated bad scripts when no eggs needed to be added:
    to ``sys.path``.
  - Fixed: Buildout didn't honour Unix umask when generating scripts.:
    https://bugs.launchpad.net/zc.buildout/+bug/180705
  - Fixed: ``update-versions-file`` didn't work unless:
    ``show-picked-versions`` was also set.
    https://github.com/buildout/buildout/issues/71
- update to version 2.0.1:
  - Fixed: buildout didn't honor umask settings when creating scripts.
  - Fix for distutils scripts installation on Python 3, related to
  ``__pycache__`` directories.
  - Fixed: encoding data in non-entry-point-based scripts was lost.
* Tue Nov  2 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 3.0.0b3:
  - New features:
  - Improve warning message when a section contains unused options. (#483)
  - Bug fixes:
  - Fix support of ``pip>=21.1`` (#567)
  - Fix confusion when using multiple Python versions and
  installing packages with C extensions
  without proper binary wheel available. (#574)
  - Development:
  - Avoid broken jobs on Travis because of security on PRs (travis-pr)
- update to version 3.0.0b2:
  - New features:
  - Improve error message when a package version is not pinned and `allow-picked-versions = false`. (#481)
  - Bug fixes:
  - Fix FileNotFoundError when installing eggs with top-level directory without code (like doc). (#556)
  - Development:
  - Login to docker hub to avoid pull limits (travis)
  - Initialize towncrier (#519)
- update to version 3.0.0b1:
  - Fix issue with combination of `>` specs and `extras` and recent `setuptools`.
  - Fix issue with incrementing options from `.buildout/default.cfg`.
  - Support python37, python38 and python39 in conditional section expressions.
  - Fix bootstrapping for python27 and python35.
- update to version 3.0.0a2:
  - Ignore `.git` when computing signature of a recipe develop egg
  - Warn when the name passed to `zc.recipe.egg:scripts`
  is not defined in egg entry points.
  - Show pip warning about Python version only once.
  - Better patch for ``pkg_resources.Distribution.hashcmp`` performance.
- update to version 3.0.0a1:
  - Scripts: ensure eggs are inserted before ``site-packages`` in ``sys.path``.
  - Fix forever loop when changing ``zc.buildout`` version via ``buildout``.
  - Add support for ``Requires-Python`` metadata.
  Fragile monkeypatch that relies on ``pip._internal``.
  Emits a warning when support is disabled due to changes in ``pip``.
  - Use ``pip install`` instead of deprecated ``setuptools.easy_install``.
  - Patch ``pkg_resources.Distribution`` to make install of unpinned versions quicker.
  Most obvious with ``setuptools``.
- update to version 2.13.3:
  - Fix DeprecationWarning about MutableMapping.
  (`#484 <https://github.com/buildout/buildout/issues/484>`_)
- update to version 2.13.2:
  - Fixed DeprecationWarning on python 3.7: "'U' mode is deprecated".
- update to version 2.13.1:
  - Documentation update for the new ``buildout query`` command.
- update to version 2.13.0:
  - Get information about the configuration with new command ``buildout query``.
- update to version 2.12.2:
  - Upon an error, buildout exits with a non-zero exit code. This now also works
  when running with ``-D``.
  - Fixed most 'Deprecation' and 'Resource' warnings.
- update to version 2.12.1:
  - zc.buildout now explicitly requests zc.recipe.egg >=2.0.6 now.
- update to version 2.12.0:
  - Add a new buildout option ``allow-unknown-extras`` to enable
  installing requirements that specify extras that do not exist. This
  needs a corresponding update to zc.recipe.egg. See `issue 457
  <https://github.com/buildout/buildout/issues/457>`_.
  zc.recipe.egg has been updated to 2.0.6 for this change.
- update to version 2.11.5:
  - Fix for `issue 295 <https://github.com/buildout/buildout/issues/295>`_. On
  windows, deletion of temporary egg files is more robust now.
- update to version 2.11.4:
  - Fix for `issue 451 <https://github.com/buildout/buildout/issues/451>`_:
  distributions with a version number that normalizes to a shorter version
  number (3.3.0 to 3.3, for instance) can be installed now.
- update to version 2.11.3:
  - Update to use the new PyPI at https://pypi.org/.
- update to version 2.11.2:
  - Fix for the #442 issue: AttributeError on
  ``pkg_resources.SetuptoolsVersion``.
- update to version 2.11.1:
  - Made upgrade check more robust. When using extensions, the improvement
  introduced in 2.11 could prevent buildout from restarting itself when it
  upgraded setuptools.
- update to version 2.11.0:
  - Installed packages are added to the working set immediately. This helps in
  some corner cases that occur when system packages have versions that
  conflict with our specified versions.
- update to version 2.10.0:
  - Setuptools 38.2.0 started supporting wheels. Through setuptools, buildout
  now also supports wheels! You need at least version 38.2.3 to get proper
  namespace support.
  This setuptools change interfered with buildout's recent support for
  `buildout.wheel <https://github.com/buildout/buildout.wheel>`_, resulting in
  a sudden "Wheels are not supported" error message (see `issue 435
  <https://github.com/buildout/buildout/issues/425>`_). Fixed by making
  setuptools the default, though you can still use the buildout.wheel if you
  want.
- update to version 2.9.6:
  - Fixed: could not install eggs when sdist file name and package name had different
  case.
- update to version 2.9.5:
  - Use HTTPS for PyPI's index.  PyPI redirects HTTP to HTTPS by default
  now so using HTTPS directly avoids the potential for that redirect
  being modified in flight.
- update to version 2.9.4:
  - Sort the distributions used to compute ``__buildout_signature__`` to
  ensure reproducibility under Python 3 or under Python 2 when ``-R``
  is used on ``PYTHONHASHSEED`` is set to ``random``. Fixes `issue 392
  <https://github.com/buildout/buildout/issues/392>`_.
  * *NOTE**: This may cause existing ``.installed.cfg`` to be
  considered outdated and lead to parts being reinstalled spuriously
  under Python 2.
  - Add support code for doctests to be able to easily measure code
  coverage. See `issue 397 <https://github.com/buildout/buildout/issues/397>`_.
- update to version 2.9.3:
  - Add more verbosity to ``annotate`` results with ``-v``
  - Select one or more sections with arguments after ``buildout annotate``.
- update to version 2.9.2:
  - Fixed: We unnecessarily used a function from newer versions of
  setuptools that caused problems when older setuptools or pkg_resources
  installs were present (as in travis.ci).
- update to version 2.9.1:
  - Fixed a minor packaging bug that broke the PyPI page.
- update to version 2.9.0:
  - Added new syntax to explicitly declare that a part depends on other part.
  See http://docs.buildout.org/en/latest/topics/implicit-parts.html
  - Internal refactoring to work with `buildout.wheel
  <https://github.com/buildout/buildout.wheel>`_.
  - Fixed a bugs in ``zc.buildout.testing.Buildout``. It was loading
  user-default configuration.  It didn't support calling the
  ``created`` method on its sections.
  - Fixed a bug (windows, py 3.4)
  When processing metadata on "old-style" distutils scripts, .exe stubs
  appeared in ``metadata_listdir``, in turn reading those burped with
  ``UnicodeDecodeError``. Skipping .exe stubs now.
- update to version 2.8.0:
  - Added a hook to enable a soon-to-be-released buildout extension to
  provide wheel support.
- update to version 2.7.1:
  - Fixed a bug introduced in 2.6.0:
  zc.buildout and its dependeoncies were reported as picked even when
  their versions were fixed in a ``versions`` section.  Worse, when the
  ``update-versions-file`` option was used, the ``versions`` section was
  updated needlessly on every run.
- update to version 2.7.0:
  - Added a buildout option, ``abi-tag-eggs`` that, when true, causes
  the `ABI tag <https://www.python.org/dev/peps/pep-0425/#abi-tag>`_
  for the buildout environment to be added to the eggs directory name.
  This is useful when switching Python implementations (e.g. CPython
  vs PyPI or debug builds vs regular builds), especially when
  environment differences aren't reflected in egg names.  It also has
  the side benefit of making eggs directories smaller, because eggs
  for different Python versions are in different directories.
- update to version 2.6.0:
  - Updated to work with the latest setuptools.
  - Added (verified) Python 3.6 support.
- update to version 2.5.3:
  - After a dist is fetched and put into its final place, compile its
  python files.  No longer wait with compiling until all dists are in
  place.  This is related to the change below about not removing an
  existing egg.  [maurits]
  - Do not remove an existing egg.  When installing an egg to a location
  that already exists, keep the current location (directory or file).
  This can only happen when the location at first did not exist and
  this changed during the buildout run.  We used to remove the
  previous location, but this could cause problems when running two
  buildouts at the same time, when they try to install the same new
  egg.  Fixes #307.  [maurits]
  - In ``zc.buildout.testing.system``, set ``TERM=dumb`` in the environment.
  This avoids invisible control characters popping up in some terminals,
  like ``xterm``.  Note that this may affect tests by buildout recipes.
  [maurits]
  - Removed Python 2.6 and 3.2 support.
  [do3cc]
- update to version 2.5.2:
  - Fixed ``-=`` and ``+=`` when extending sections. See #161.
  [puittenbroek]
- update to version 2.5.1:
  - Fix python 2 for downloading external config files with basic auth in the
  URL. Fixes #257.
- update to version 2.5.0:
  - Added more elaborate version and requirement information when there's a
  version conflict. Previously, you could get a report of a version conflict
  without information about which dependency requested the conflicing
  requirement.
  Now all this information is logged and displayed in case of an error.
  [reinout]
  - Dropped 3.2 support (at least in the automatic tests) as setuptools will
  soon stop supporting it. Added python 3.5 to the automatic tests.
  [reinout]
- update to version 2.4.7:
  - Fix for #279. Distutils script detection previously broke on windows with
  python 3 because it errored on ``.exe`` files.
  [reinout]
- update to version 2.4.6:
  - Relative paths are now also correctly generated for the current directory
  ("develop = .").
  [youngking]
- update to version 2.4.5:
  - More complete fix for #24. Distutils scripts are now also generated for
  develop eggs.
  [reinout]
- update to version 2.4.4:
  - zc.buildout is now also released as a wheel. (Note: buildout itself doesn't
  support installing wheels yet.)
  [graingert]
- update to version 2.4.3:
  - Added nested directory creation support
  [guyzmo]
- update to version 2.4.2:
  - If a downloaded config file in the "extends-cache" gets corrupted, buildout
  now tells you the filename in the cache. Handy for troubleshooting.
  [reinout]
- update to version 2.4.1:
  - Check the ``use-dependency-links`` option earlier.  This can give
  a small speed increase.
  [maurits]
  - When using python 2, urllib2 is used to work around Python issue 24599, which
  affects downloading from behind a proxy.
  [stefano-m]
- update to version 2.4.0:
  - Buildout no longer breaks on packages that contain a file with a non-ascii
  filename. Fixes #89 and #148.
  [reinout]
  - Undo breakage on Windows machines where ``sys.prefix`` can also be a
  ``site-packages`` directory:  don't remove it from ``sys.path``.  See
  https://github.com/buildout/buildout/issues/217 .
  - Remove assumption that ``pkg_resources`` is a module (untrue since
  release of `setuptools 8.3``).  See
  https://github.com/buildout/buildout/issues/227 .
  - Fix for #212. For certain kinds of conflict errors you'd get an UnpackError
  when rendering the error message. Instead of a nicely formatted version
  conflict message.
  [reinout]
  - Making sure we use the correct easy_install when setuptools is installed
  globally. See https://github.com/buildout/buildout/pull/232 and
  https://github.com/buildout/buildout/pull/222 .
  [lrowe]
  - Updated buildout's `travis-ci <https://travis-ci.org/buildout/buildout>`_
  configuration so that tests run much quicker so that buildout is easier and
  quicker to develop.
  [reinout]
  - Note: zc.recipe.egg has also been updated to 2.0.2 together with this
  zc.buildout release. Fixed: In ``zc.recipe.egg#custom`` recipe's ``rpath``
  support, don't assume path elements are buildout-relative if they start with
  one of the "special" tokens (e.g., ``$ORIGIN``).  See:
  https://github.com/buildout/buildout/issues/225.
  [tseaver]
  - ``download-cache``, ``eggs-directory`` and ``extends-cache`` are now
  automatically created if their parent directory exists. Also they can be
  relative directories (relative to the location of the buildout config file
  that defines them). Also they can now be in the form ``~/subdir``, with the
  usual convention that the ``~`` char means the home directory of the user
  running buildout.
  [lelit]
  - A new boostrap.py file is released (version 2015-07-01).
  - When bootstrapping, the ``develop-eggs/`` directory is first removed. This
  prevents old left-over ``.egg-link`` files from breaking buildout's careful
  package collection mechanism.
  [reinout]
  - The bootstrap script now accepts ``--to-dir``. Setuptools is installed
  there. If already available there, it is reused. This can be used to
  bootstrap buildout without internet access. Similarly, a local
  ``ez_setup.py`` is used when available instead of it being downloaded. You
  need setuptools 14.0 or higher for this functionality.
  [lrowe]
  - The bootstrap script now uses ``--buildout-version`` instead of
  ``--version`` to pick a specific buildout version.
  [reinout]
  - The bootstrap script now accepts ``--version`` which prints the bootstrap
  version. This version is the date the bootstrap.py was last changed. A date
  is handier or less confusing than either tracking zc.buildout's version or
  having a separate bootstrap version number.
  [reinout]
- update to version 2.3.1:
  - Fixed: Buildout merged single-version requirements with
  version-range requirements in a way that caused it to think there
  wasn't a single-version requirement.  IOW, buildout throught that
  versions were being picked when they weren't.
  - Suppress spurios (and possibly non-spurious) version-parsing warnings.
- update to version 2.3.0:
  - Buildout is now compatible with (and requires) setuptools 8.
- update to version 2.2.5:
  - Improved fix for #198: when bootstrapping with an extension, buildout was
  too strict on itself, resulting in an inability to upgrade or downgrade its
  own version.
  [reinout]
  - Setuptools must be at 3.3 or higher now. If you use the latest bootstrap
  from http://downloads.buildout.org/2/bootstrap.py you're all set.
  [reinout]
  - Installing *recipes* that themselves have dependencies used to fail with a
  VersionConflict if such a dependency was installed globally with a lower
  version. Buildout now ignores the version conflict in those cases and simply
  installs the correct version.
  [reinout]
- update to version 2.2.4:
  - Fix for #198: buildout 2.2.3 caused a version conflict when bootstrapping a
  buildout with a version pinned to an earlier one. Same version conflict
  could occur with system-wide installed packages that were newer than the
  pinned version.
  [reinout]
- update to version 2.2.3:
  - Fix #197, Python 3 regression
  [aclark4life]
- update to version 2.2.2:
  - Open files for ``exec()`` in universal newlines mode.  See
  https://github.com/buildout/buildout/issues/130
  - Add ``BUILDOUT_HOME`` as an alternate way to control how the user default
  configuration is found.
  - Close various files when finished writing to them. This avoids
  ResourceWarnings on Python 3, and better supports doctests under PyPy.
  - Introduce improved easy_install Install.install function. This is present
  in 1.5.X and 1.7X but was never merged into 2.X somehow.
- update to version 2.2.1:
  - ``distutils`` scripts: correct order of operations on ``from ... import``
  lines (see https://github.com/buildout/buildout/issues/134).
  - Add an ``--allow-site-packges`` option to ``bootstrap.py``, defaulting
  to False.  If the value is false, strip any "site packages" (as defined by
  the ``site`` module) from ``sys.path`` before attempting to import
  ``setuptools`` / ``pkg_resources``.
  - Updated the URL used to fetch ``ez_setup.py`` to the official, non-version-
  pinned version.
- update to version 2.2.0:
  - Handle both addition and subtraction of elements (+= and -=) on the same key
  in the same section. Forward-ported from buildout 1.6.
  - Suppress the useless ``Link to <URL> ***BLOCKED*** by --allow-hosts``
  error message being emitted by distribute / setuptools.
  - Extend distutils script generation to support module docstrings and
  __future__ imports.
  - Refactored picked versions logic to make it easier to use for plugins.
  - Use ``get_win_launcher`` API to find Windows launcher (falling back to
  ``resource_string`` for ``cli.exe``).
  - Remove ``data_files`` from ``setup.py``:  it was installing ``README.txt``
  in current directory during installation (merged from 1.x branch).
  - Switch dependency from ``distribute 0.6.x`` to ``setuptools 0.7.x``.
- update to version 2.1.0:
  - Meta-recipe support
  - Conditional sections
  - Buildout now accepts a ``--version`` command-line option to print
  its version.
  - Fixed: Builout didn't exit with a non-zero exit status if there was a:
    failure in combination with an upgrade.
  - Fixed: We now fail with an informative error when an old bootstrap:
    script causes buildout 2 to be used with setuptools.
  - Fixed: An error incorrectly suggested that buildout 2 implemented all:
    of the functionality of dumppickedversions.
  - Fixed: Buildout generated bad scripts when no eggs needed to be added:
    to ``sys.path``.
  - Fixed: Buildout didn't honour Unix umask when generating scripts.:
    https://bugs.launchpad.net/zc.buildout/+bug/180705
  - Fixed: ``update-versions-file`` didn't work unless:
    ``show-picked-versions`` was also set.
    https://github.com/buildout/buildout/issues/71
- update to version 2.0.1:
  - Fixed: buildout didn't honor umask settings when creating scripts.
  - Fix for distutils scripts installation on Python 3, related to
  ``__pycache__`` directories.
  - Fixed: encoding data in non-entry-point-based scripts was lost.
* Mon Mar  8 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 2.13.4:
  - Pin `setuptools` < 52 as setuptools removed support for `easy_install` in
    newer versions.
    (`#543 <https://github.com/buildout/buildout/issues/543>`_)
  - Support for Python 3.4 is no longer tested using automatic tests.
  - Add support for Python 3.7 and 3.8.
* Fri May 15 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Mar  9 2020 pgajdos@suse.com
- version update to 2.13.3
  - Fix DeprecationWarning about MutableMapping.
  (`#484 <https://github.com/buildout/buildout/issues/484>`_)
* Sat Jul  6 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Uodate to version 2.13.2:
  - Fixed DeprecationWarning on python 3.7: "'U' mode is deprecated".
* Sat Feb 16 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 2.13.1:
  - Documentation update for the new ``buildout query`` command.
* Sun Jan 27 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 2.13.0:
  * Get information about the configuration with new command ``buildout query``.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Sep 17 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.12.2:
  - Upon an error, buildout exits with a non-zero exit code. This now also works
  when running with ``-D``.
  - Fixed most 'Deprecation' and 'Resource' warnings.
- update to version 2.12.1:
  - zc.buildout now explicitly requests zc.recipe.egg >=2.0.6 now.
* Sat Jul  7 2018 sebix+novell.com@sebix.at
- update to version 2.12.0:
  - Add a new buildout option ``allow-unknown-extras`` to enable
  installing requirements that specify extras that do not exist. This
  needs a corresponding update to zc.recipe.egg. See `issue 457
  <https://github.com/buildout/buildout/issues/457>`_.
  zc.recipe.egg has been updated to 2.0.6 for this change.
- update to version 2.11.5:
  - Fix for `issue 295 <https://github.com/buildout/buildout/issues/295>`_. On
  windows, deletion of temporary egg files is more robust now.
* Mon May 21 2018 sebix+novell.com@sebix.at
- update to version 2.11.4:
  - Fix for `issue 451 <https://github.com/buildout/buildout/issues/451>`:
  distributions with a version number that normalizes to a shorter version
  number (3.3.0 to 3.3, for instance) can be installed now.
* Sat Apr 14 2018 sebix+novell.com@sebix.at
- update to version 2.11.3:
  - Update to use the new PyPI at https://pypi.org/.
* Mon Mar 19 2018 sebix+novell.com@sebix.at
- update to version 2.11.2:
  - Fix for the #442 issue: AttributeError on
  ``pkg_resources.SetuptoolsVersion``.
* Fri Mar  2 2018 sebix+novell.com@sebix.at
- update to version 2.11.1:
  - Made upgrade check more robust. When using extensions, the improvement
  introduced in 2.11 could prevent buildout from restarting itself when it
  upgraded setuptools.
* Sun Jan 21 2018 sebix+novell.com@sebix.at
- update to version 2.11.0:
  - Installed packages are added to the working set immediately. This helps in
  some corner cases that occur when system packages have versions that
  conflict with our specified versions.
- update to verion 2.10.0
  - Setuptools 38.2.0 started supporting wheels. Through setuptools, buildout
  now also supports wheels! You need at least version 38.2.3 to get proper
  namespace support.
  This setuptools change interfered with buildout's recent support for
  buildout.wheel <https://github.com/buildout/buildout.wheel>, resulting in
  a sudden "Wheels are not supported" error message (see issue 435
  <https://github.com/buildout/buildout/issues/425>). Fixed by making
  setuptools the default, though you can still use the buildout.wheel if you
  want.
- remove test boundary condition from specfile
* Fri Dec  1 2017 sebix+novell.com@sebix.at
- update to 2.9.6:
  * Fixed: could not install eggs when sdist file name and package name had different case.
* Sat Sep 23 2017 sebix+novell.com@sebix.at
- update to 2.9.5
  * Use HTTPS for PyPI's index.  PyPI redirects HTTP to HTTPS by default
  now so using HTTPS directly avoids the potential for that redirect
  being modified in flight.
* Sat Aug 19 2017 sebix+novell.com@sebix.at
- singlespec
- update to 2.9.4
- rename to python-zc.buildout
* Sun Sep 29 2013 p.drouand@gmail.com
- Update to version 2.2.1
  + distutils scripts: correct order of operations on from ... import
    lines (see https://github.com/buildout/buildout/issues/134).
  + Add an --allow-site-packges option to bootstrap.py, defaulting to False.
    If the value is false, strip any "site packages" (as defined by the
    site module) from sys.path before attempting to import setuptools / pkg_resources.
  + Updated the URL used to fetch ez_setup.py to the official,
    non-version- pinned version.
- Changes between version 2.2.0 and 2.1.0
  + Handle both addition and subtraction of elements (+= and -=) on
    the same key in the same section. Forward-ported from buildout 1.6.
  + Suppress the useless Link to <URL> ***BLOCKED*** by --allow-hosts error
    message being emitted by distribute / setuptools.
  + Extend distutils script generation to support module docstrings and
  _future__ imports.
  + Refactored picked versions logic to make it easier to use for plugins.
  + Use get_win_launcher API to find Windows launcher (falling back to resource
  _string for cli.exe).
  + Remove data_files from setup.py: it was installing README.txt in current
    directory during installation (merged from 1.x branch).
  + Switch dependency from distribute 0.6.x to setuptools 0.7.x.
- Use download url as source url
- Replace python-distribute with python-setuptools BuildRequires
- Add documentation from tarball
* Mon Mar 25 2013 alexandre@exatati.com.br
- Update to 2.1.0:
  - Meta-recipe support
  - Conditional sections
  - Buildout now accepts a --version command-line option to print
    its version.
  Fixed: Builout didn't exit with a non-zero exit status if there was a
    failure in combination with an upgrade.
  Fixed: We now fail with an informative error when an old bootstrap
    script causes buildout 2 to be used with setuptools.
  Fixed: An error incorrectly suggested that buildout 2 implemented all
    of the functionality of dumppickedversions.
  Fixed: Buildout generated bad scripts when no eggs needed to be added
    to sys.path.
  Fixed: Buildout didn't honour Unix umask when generating scripts.
    https://bugs.launchpad.net/zc.buildout/+bug/180705
  Fixed: update-versions-file didn't work unless
    show-picked-versions was also set.
    https://github.com/buildout/buildout/issues/71
* Thu Feb 21 2013 p.drouand@gmail.com
- Update to version 1.7.1:
  * Fixed: Constraints intended to prevent upgrading to
    buildout-2-compatible recipes weren't expressed correctly, leading to
    unintendional use of zc.recipe.egg-2.0.0a3.
- Update to version 1.7.0:
  * Unless version requirements are specified, buildout won't upgrade
    itself past version 1.
  * Versions in versions sections can now be simple constraints, like <2.0dev
    in addition to being simple versions.
  * This is used to prevent upgrading zc.recipe.egg and zc.recipe.testrunner
    past version 1.
  * If buildout is bootstrapped with a non-final release, it won't downgrade
    itself to a final release.
  * Fix: distribute 0.6.33 broke Python 2.4 compatibility
    remove data_files from setup.py, which was installing README.txt in
    current directory during installation [Domen Kožar]
    Windows fix: use cli-64.exe/cli.exe depending on 64/32 bit and try cli.exe
    if cli-64.exe is not found, fixing 9c6be7ac6d218f09e33725e07dccc4af74d8cf97
  * Windows fix: buildout init was broken, re.sub does not like a single backslash
  * fixed all builds on travis-ci
    use os._exit insted of sys.exit after ugrade forking
    Revert cfa0478937d16769c268bf51e60e69cd3ead50f3, it only broke a feature
* Tue Mar 13 2012 alexandre@exatati.com.br
- Regenerate spec file with py2pack.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Oct 13 2010 alexandre@exatati.com.br
- Update to 1.5.2.
* Mon Aug 30 2010 alexandre@exatati.com.br
- Update to 1.5.1.
* Wed Aug 25 2010 alexandre@exatati.com.br
- Update to 1.5.0.
* Fri Aug 20 2010 alexandre@exatati.com.br
- Update to 1.4.4.
* Sat May  1 2010 alexandre@exatati.com.br
- Update to 1.5.0b2.
* Mon Nov  2 2009 alexandre@exatati.com.br
- Update to 1.4.2.
* Fri Oct 16 2009 alexandre@exatati.com.br
- Initial package (1.4.1) for openSUSE.
